@@ -472,6 +472,41 @@ return array (
                 ),
             ),
         ),
+        'GetTemplateSummary' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\QueryCommand',
+            'responseClass' => 'GetTemplateSummaryOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Action' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => 'GetTemplateSummary',
+                ),
+                'Version' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => '2010-05-15',
+                ),
+                'TemplateBody' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                ),
+                'TemplateURL' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                    'maxLength' => 1024,
+                ),
+                'StackName' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                ),
+            ),
+        ),
         'ListStackResources' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -572,6 +607,48 @@ return array (
                 ),
             ),
         ),
+        'SignalResource' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\QueryCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Action' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => 'SignalResource',
+                ),
+                'Version' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => '2010-05-15',
+                ),
+                'StackName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                ),
+                'LogicalResourceId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+                'UniqueId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                    'maxLength' => 64,
+                ),
+                'Status' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+            ),
+        ),
         'UpdateStack' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -1013,6 +1090,76 @@ return array (
                 ),
             ),
         ),
+        'GetTemplateSummaryOutput' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'Parameters' => array(
+                    'type' => 'array',
+                    'location' => 'xml',
+                    'items' => array(
+                        'name' => 'ParameterDeclaration',
+                        'type' => 'object',
+                        'sentAs' => 'member',
+                        'properties' => array(
+                            'ParameterKey' => array(
+                                'type' => 'string',
+                            ),
+                            'DefaultValue' => array(
+                                'type' => 'string',
+                            ),
+                            'ParameterType' => array(
+                                'type' => 'string',
+                            ),
+                            'NoEcho' => array(
+                                'type' => 'boolean',
+                            ),
+                            'Description' => array(
+                                'type' => 'string',
+                            ),
+                            'ParameterConstraints' => array(
+                                'type' => 'object',
+                                'properties' => array(
+                                    'AllowedValues' => array(
+                                        'type' => 'array',
+                                        'items' => array(
+                                            'name' => 'AllowedValue',
+                                            'type' => 'string',
+                                            'sentAs' => 'member',
+                                        ),
+                                    ),
+                                ),
+                            ),
+                        ),
+                    ),
+                ),
+                'Description' => array(
+                    'type' => 'string',
+                    'location' => 'xml',
+                ),
+                'Capabilities' => array(
+                    'type' => 'array',
+                    'location' => 'xml',
+                    'items' => array(
+                        'name' => 'Capability',
+                        'type' => 'string',
+                        'sentAs' => 'member',
+                    ),
+                ),
+                'CapabilitiesReason' => array(
+                    'type' => 'string',
+                    'location' => 'xml',
+                ),
+                'Version' => array(
+                    'type' => 'string',
+                    'location' => 'xml',
+                ),
+                'Metadata' => array(
+                    'type' => 'string',
+                    'location' => 'xml',
+                ),
+            ),
+        ),
         'ListStackResourcesOutput' => array(
             'type' => 'object',
             'additionalProperties' => true,
