@@ -111,6 +111,14 @@ return array (
                     'format' => 'boolean-string',
                     'location' => 'json',
                 ),
+                'CloudWatchLogsLogGroupArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'CloudWatchLogsRoleArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
             ),
             'errorResponses' => array(
                 array(
@@ -149,6 +157,18 @@ return array (
                     'reason' => 'This exception is thrown when the provided trail name is not valid.',
                     'class' => 'InvalidTrailNameException',
                 ),
+                array(
+                    'reason' => 'This exception is thrown when the provided CloudWatch log group is not valid.',
+                    'class' => 'InvalidCloudWatchLogsLogGroupArnException',
+                ),
+                array(
+                    'reason' => 'This exception is thrown when the provided role is not valid.',
+                    'class' => 'InvalidCloudWatchLogsRoleArnException',
+                ),
+                array(
+                    'reason' => 'Cannot set a CloudWatch Logs delivery for this region.',
+                    'class' => 'CloudWatchLogsDeliveryUnavailableException',
+                ),
             ),
         ),
         'DeleteTrail' => array(
@@ -258,6 +278,93 @@ return array (
                 ),
             ),
         ),
+        'LookupEvents' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'LookupEventsResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'com.amazonaws.cloudtrail.v20131101.CloudTrail_20131101.LookupEvents',
+                ),
+                'LookupAttributes' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'LookupAttribute',
+                        'type' => 'object',
+                        'properties' => array(
+                            'AttributeKey' => array(
+                                'required' => true,
+                                'type' => 'string',
+                            ),
+                            'AttributeValue' => array(
+                                'required' => true,
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+                'StartTime' => array(
+                    'type' => array(
+                        'object',
+                        'string',
+                        'integer',
+                    ),
+                    'format' => 'date-time',
+                    'location' => 'json',
+                ),
+                'EndTime' => array(
+                    'type' => array(
+                        'object',
+                        'string',
+                        'integer',
+                    ),
+                    'format' => 'date-time',
+                    'location' => 'json',
+                ),
+                'MaxResults' => array(
+                    'type' => 'numeric',
+                    'location' => 'json',
+                    'minimum' => 1,
+                    'maximum' => 50,
+                ),
+                'NextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Occurs when an invalid lookup attribute is specified.',
+                    'class' => 'InvalidLookupAttributesException',
+                ),
+                array(
+                    'reason' => 'Occurs if the timestamp values are invalid. Either the start time occurs after the end time or the time range is outside the range of possible values.',
+                    'class' => 'InvalidTimeRangeException',
+                ),
+                array(
+                    'reason' => 'This exception is thrown if the limit specified is invalid.',
+                    'class' => 'InvalidMaxResultsException',
+                ),
+                array(
+                    'reason' => 'Invalid token or token that was previously used in a request with different parameters. This exception is thrown if the token is invalid.',
+                    'class' => 'InvalidNextTokenException',
+                ),
+            ),
+        ),
         'StartLogging' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -377,6 +484,14 @@ return array (
                     'format' => 'boolean-string',
                     'location' => 'json',
                 ),
+                'CloudWatchLogsLogGroupArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'CloudWatchLogsRoleArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
             ),
             'errorResponses' => array(
                 array(
@@ -411,6 +526,18 @@ return array (
                     'reason' => 'This exception is thrown when the provided trail name is not valid.',
                     'class' => 'InvalidTrailNameException',
                 ),
+                array(
+                    'reason' => 'This exception is thrown when the provided CloudWatch log group is not valid.',
+                    'class' => 'InvalidCloudWatchLogsLogGroupArnException',
+                ),
+                array(
+                    'reason' => 'This exception is thrown when the provided role is not valid.',
+                    'class' => 'InvalidCloudWatchLogsRoleArnException',
+                ),
+                array(
+                    'reason' => 'Cannot set a CloudWatch Logs delivery for this region.',
+                    'class' => 'CloudWatchLogsDeliveryUnavailableException',
+                ),
             ),
         ),
     ),
@@ -439,6 +566,14 @@ return array (
                     'type' => 'boolean',
                     'location' => 'json',
                 ),
+                'CloudWatchLogsLogGroupArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'CloudWatchLogsRoleArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
             ),
         ),
         'EmptyOutput' => array(
@@ -471,6 +606,12 @@ return array (
                             'IncludeGlobalServiceEvents' => array(
                                 'type' => 'boolean',
                             ),
+                            'CloudWatchLogsLogGroupArn' => array(
+                                'type' => 'string',
+                            ),
+                            'CloudWatchLogsRoleArn' => array(
+                                'type' => 'string',
+                            ),
                         ),
                     ),
                 ),
@@ -508,6 +649,64 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                 ),
+                'LatestCloudWatchLogsDeliveryError' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'LatestCloudWatchLogsDeliveryTime' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+            ),
+        ),
+        'LookupEventsResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'Events' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'Event',
+                        'type' => 'object',
+                        'properties' => array(
+                            'EventId' => array(
+                                'type' => 'string',
+                            ),
+                            'EventName' => array(
+                                'type' => 'string',
+                            ),
+                            'EventTime' => array(
+                                'type' => 'string',
+                            ),
+                            'Username' => array(
+                                'type' => 'string',
+                            ),
+                            'Resources' => array(
+                                'type' => 'array',
+                                'items' => array(
+                                    'name' => 'Resource',
+                                    'type' => 'object',
+                                    'properties' => array(
+                                        'ResourceType' => array(
+                                            'type' => 'string',
+                                        ),
+                                        'ResourceName' => array(
+                                            'type' => 'string',
+                                        ),
+                                    ),
+                                ),
+                            ),
+                            'CloudTrailEvent' => array(
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+                'NextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
             ),
         ),
         'UpdateTrailResponse' => array(
@@ -534,6 +733,14 @@ return array (
                     'type' => 'boolean',
                     'location' => 'json',
                 ),
+                'CloudWatchLogsLogGroupArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'CloudWatchLogsRoleArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
             ),
         ),
     ),
