@@ -124,6 +124,54 @@ return array (
                 ),
             ),
         ),
+        'DeleteDestination' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.DeleteDestination',
+                ),
+                'destinationName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if the specified resource does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Returned if multiple requests to update the same resource were in conflict.',
+                    'class' => 'OperationAbortedException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
         'DeleteLogGroup' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -162,10 +210,6 @@ return array (
                     'reason' => 'Returned if the specified resource does not exist.',
                     'class' => 'ResourceNotFoundException',
                 ),
-                array(
-                    'reason' => 'Returned if the resource cannot be deleted because other resources are still associated with it.',
-                    'class' => 'ResourceInUseException',
-                ),
                 array(
                     'reason' => 'Returned if multiple requests to update the same resource were in conflict.',
                     'class' => 'OperationAbortedException',
@@ -334,6 +378,111 @@ return array (
                 ),
             ),
         ),
+        'DeleteSubscriptionFilter' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.DeleteSubscriptionFilter',
+                ),
+                'logGroupName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'filterName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if the specified resource does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Returned if multiple requests to update the same resource were in conflict.',
+                    'class' => 'OperationAbortedException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
+        'DescribeDestinations' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'DescribeDestinationsResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.DescribeDestinations',
+                ),
+                'DestinationNamePrefix' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'nextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'limit' => array(
+                    'type' => 'numeric',
+                    'location' => 'json',
+                    'minimum' => 1,
+                    'maximum' => 50,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
         'DescribeLogGroups' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -364,6 +513,7 @@ return array (
                 'nextToken' => array(
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
                 ),
                 'limit' => array(
                     'type' => 'numeric',
@@ -417,9 +567,19 @@ return array (
                     'minLength' => 1,
                     'maxLength' => 512,
                 ),
+                'orderBy' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'descending' => array(
+                    'type' => 'boolean',
+                    'format' => 'boolean-string',
+                    'location' => 'json',
+                ),
                 'nextToken' => array(
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
                 ),
                 'limit' => array(
                     'type' => 'numeric',
@@ -480,6 +640,7 @@ return array (
                 'nextToken' => array(
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
                 ),
                 'limit' => array(
                     'type' => 'numeric',
@@ -503,6 +664,152 @@ return array (
                 ),
             ),
         ),
+        'DescribeSubscriptionFilters' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'DescribeSubscriptionFiltersResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.DescribeSubscriptionFilters',
+                ),
+                'logGroupName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'filterNamePrefix' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'nextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'limit' => array(
+                    'type' => 'numeric',
+                    'location' => 'json',
+                    'minimum' => 1,
+                    'maximum' => 50,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if the specified resource does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
+        'FilterLogEvents' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'FilterLogEventsResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.FilterLogEvents',
+                ),
+                'logGroupName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'logStreamNames' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'minItems' => 1,
+                    'maxItems' => 100,
+                    'items' => array(
+                        'name' => 'LogStreamName',
+                        'type' => 'string',
+                        'minLength' => 1,
+                        'maxLength' => 512,
+                    ),
+                ),
+                'startTime' => array(
+                    'type' => 'numeric',
+                    'location' => 'json',
+                ),
+                'endTime' => array(
+                    'type' => 'numeric',
+                    'location' => 'json',
+                ),
+                'filterPattern' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                    'maxLength' => 512,
+                ),
+                'nextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'limit' => array(
+                    'type' => 'numeric',
+                    'location' => 'json',
+                    'minimum' => 1,
+                    'maximum' => 10000,
+                ),
+                'interleaved' => array(
+                    'type' => 'boolean',
+                    'format' => 'boolean-string',
+                    'location' => 'json',
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if the specified resource does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
         'GetLogEvents' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -549,6 +856,7 @@ return array (
                 'nextToken' => array(
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
                 ),
                 'limit' => array(
                     'type' => 'numeric',
@@ -577,6 +885,112 @@ return array (
                 ),
             ),
         ),
+        'PutDestination' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'PutDestinationResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.PutDestination',
+                ),
+                'destinationName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'targetArn' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'roleArn' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if multiple requests to update the same resource were in conflict.',
+                    'class' => 'OperationAbortedException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
+        'PutDestinationPolicy' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.PutDestinationPolicy',
+                ),
+                'destinationName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'accessPolicy' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if multiple requests to update the same resource were in conflict.',
+                    'class' => 'OperationAbortedException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
         'PutLogEvents' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -617,7 +1031,7 @@ return array (
                     'type' => 'array',
                     'location' => 'json',
                     'minItems' => 1,
-                    'maxItems' => 1000,
+                    'maxItems' => 10000,
                     'items' => array(
                         'name' => 'InputLogEvent',
                         'type' => 'object',
@@ -630,7 +1044,6 @@ return array (
                                 'required' => true,
                                 'type' => 'string',
                                 'minLength' => 1,
-                                'maxLength' => 32768,
                             ),
                         ),
                     ),
@@ -812,6 +1225,82 @@ return array (
                 ),
             ),
         ),
+        'PutSubscriptionFilter' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Logs_20140328.PutSubscriptionFilter',
+                ),
+                'logGroupName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'filterName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 512,
+                ),
+                'filterPattern' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'maxLength' => 512,
+                ),
+                'destinationArn' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+                'roleArn' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Returned if a parameter of the request is incorrectly specified.',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Returned if the specified resource does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Returned if multiple requests to update the same resource were in conflict.',
+                    'class' => 'OperationAbortedException',
+                ),
+                array(
+                    'reason' => 'Returned if you have reached the maximum number of resources that can be created.',
+                    'class' => 'LimitExceededException',
+                ),
+                array(
+                    'reason' => 'Returned if the service cannot complete the request.',
+                    'class' => 'ServiceUnavailableException',
+                ),
+            ),
+        ),
         'TestMetricFilter' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -849,7 +1338,6 @@ return array (
                         'name' => 'EventMessage',
                         'type' => 'string',
                         'minLength' => 1,
-                        'maxLength' => 32768,
                     ),
                 ),
             ),
@@ -870,6 +1358,44 @@ return array (
             'type' => 'object',
             'additionalProperties' => true,
         ),
+        'DescribeDestinationsResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'destinations' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'Destination',
+                        'type' => 'object',
+                        'properties' => array(
+                            'destinationName' => array(
+                                'type' => 'string',
+                            ),
+                            'targetArn' => array(
+                                'type' => 'string',
+                            ),
+                            'roleArn' => array(
+                                'type' => 'string',
+                            ),
+                            'accessPolicy' => array(
+                                'type' => 'string',
+                            ),
+                            'arn' => array(
+                                'type' => 'string',
+                            ),
+                            'creationTime' => array(
+                                'type' => 'numeric',
+                            ),
+                        ),
+                    ),
+                ),
+                'nextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+            ),
+        ),
         'DescribeLogGroupsResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
@@ -999,6 +1525,95 @@ return array (
                 ),
             ),
         ),
+        'DescribeSubscriptionFiltersResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'subscriptionFilters' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'SubscriptionFilter',
+                        'type' => 'object',
+                        'properties' => array(
+                            'filterName' => array(
+                                'type' => 'string',
+                            ),
+                            'logGroupName' => array(
+                                'type' => 'string',
+                            ),
+                            'filterPattern' => array(
+                                'type' => 'string',
+                            ),
+                            'destinationArn' => array(
+                                'type' => 'string',
+                            ),
+                            'roleArn' => array(
+                                'type' => 'string',
+                            ),
+                            'creationTime' => array(
+                                'type' => 'numeric',
+                            ),
+                        ),
+                    ),
+                ),
+                'nextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+            ),
+        ),
+        'FilterLogEventsResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'events' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'FilteredLogEvent',
+                        'type' => 'object',
+                        'properties' => array(
+                            'logStreamName' => array(
+                                'type' => 'string',
+                            ),
+                            'timestamp' => array(
+                                'type' => 'numeric',
+                            ),
+                            'message' => array(
+                                'type' => 'string',
+                            ),
+                            'ingestionTime' => array(
+                                'type' => 'numeric',
+                            ),
+                            'eventId' => array(
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+                'searchedLogStreams' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'SearchedLogStream',
+                        'type' => 'object',
+                        'properties' => array(
+                            'logStreamName' => array(
+                                'type' => 'string',
+                            ),
+                            'searchedCompletely' => array(
+                                'type' => 'boolean',
+                            ),
+                        ),
+                    ),
+                ),
+                'nextToken' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+            ),
+        ),
         'GetLogEventsResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
@@ -1032,6 +1647,36 @@ return array (
                 ),
             ),
         ),
+        'PutDestinationResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'destination' => array(
+                    'type' => 'object',
+                    'location' => 'json',
+                    'properties' => array(
+                        'destinationName' => array(
+                            'type' => 'string',
+                        ),
+                        'targetArn' => array(
+                            'type' => 'string',
+                        ),
+                        'roleArn' => array(
+                            'type' => 'string',
+                        ),
+                        'accessPolicy' => array(
+                            'type' => 'string',
+                        ),
+                        'arn' => array(
+                            'type' => 'string',
+                        ),
+                        'creationTime' => array(
+                            'type' => 'numeric',
+                        ),
+                    ),
+                ),
+            ),
+        ),
         'PutLogEventsResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
@@ -1040,6 +1685,21 @@ return array (
                     'type' => 'string',
                     'location' => 'json',
                 ),
+                'rejectedLogEventsInfo' => array(
+                    'type' => 'object',
+                    'location' => 'json',
+                    'properties' => array(
+                        'tooNewLogEventStartIndex' => array(
+                            'type' => 'numeric',
+                        ),
+                        'tooOldLogEventEndIndex' => array(
+                            'type' => 'numeric',
+                        ),
+                        'expiredLogEventEndIndex' => array(
+                            'type' => 'numeric',
+                        ),
+                    ),
+                ),
             ),
         ),
         'TestMetricFilterResponse' => array(
@@ -1072,6 +1732,12 @@ return array (
         ),
     ),
     'iterators' => array(
+        'DescribeDestinations' => array(
+            'input_token' => 'nextToken',
+            'output_token' => 'nextToken',
+            'limit_key' => 'limit',
+            'result_key' => 'destinations',
+        ),
         'DescribeLogGroups' => array(
             'input_token' => 'nextToken',
             'output_token' => 'nextToken',
