@@ -23,13 +23,6 @@ return array (
     'targetPrefix' => 'AWSCognitoIdentityService.',
     'signatureVersion' => 'v4',
     'namespace' => 'CognitoIdentity',
-    'regions' => array(
-        'us-east-1' => array(
-            'http' => false,
-            'https' => true,
-            'hostname' => 'cognito-identity.us-east-1.amazonaws.com',
-        ),
-    ),
     'operations' => array(
         'CreateIdentityPool' => array(
             'httpMethod' => 'POST',
@@ -74,7 +67,7 @@ return array (
                         'maxLength' => 128,
                         'data' => array(
                             'shape_name' => 'IdentityProviderName',
-                            'key_pattern' => '/[\\w._-]+/',
+                            'key_pattern' => '/[\\w._/-]+/',
                         ),
                     ),
                 ),
@@ -88,7 +81,7 @@ return array (
                     'type' => 'array',
                     'location' => 'json',
                     'items' => array(
-                        'name' => 'OIDCProviderARN',
+                        'name' => 'ARNString',
                         'type' => 'string',
                         'minLength' => 20,
                         'maxLength' => 2048,
@@ -122,6 +115,56 @@ return array (
                 ),
             ),
         ),
+        'DeleteIdentities' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'DeleteIdentitiesResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'AWSCognitoIdentityService.DeleteIdentities',
+                ),
+                'IdentityIdsToDelete' => array(
+                    'required' => true,
+                    'type' => 'array',
+                    'location' => 'json',
+                    'minItems' => 1,
+                    'maxItems' => 60,
+                    'items' => array(
+                        'name' => 'IdentityId',
+                        'type' => 'string',
+                        'minLength' => 1,
+                        'maxLength' => 50,
+                    ),
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Thrown for missing or bad input parameter(s).',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Thrown when a request is throttled.',
+                    'class' => 'TooManyRequestsException',
+                ),
+                array(
+                    'reason' => 'Thrown when the service encounters an error during processing the request.',
+                    'class' => 'InternalErrorException',
+                ),
+            ),
+        ),
         'DeleteIdentityPool' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -174,6 +217,58 @@ return array (
                 ),
             ),
         ),
+        'DescribeIdentity' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'IdentityDescription',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'AWSCognitoIdentityService.DescribeIdentity',
+                ),
+                'IdentityId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 50,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Thrown for missing or bad input parameter(s).',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Thrown when the requested resource (for example, a dataset or record) does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Thrown when a user is not authorized to access the requested resource.',
+                    'class' => 'NotAuthorizedException',
+                ),
+                array(
+                    'reason' => 'Thrown when a request is throttled.',
+                    'class' => 'TooManyRequestsException',
+                ),
+                array(
+                    'reason' => 'Thrown when the service encounters an error during processing the request.',
+                    'class' => 'InternalErrorException',
+                ),
+            ),
+        ),
         'DescribeIdentityPool' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -226,6 +321,83 @@ return array (
                 ),
             ),
         ),
+        'GetCredentialsForIdentity' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'GetCredentialsForIdentityResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'AWSCognitoIdentityService.GetCredentialsForIdentity',
+                ),
+                'IdentityId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 50,
+                ),
+                'Logins' => array(
+                    'type' => 'object',
+                    'location' => 'json',
+                    'additionalProperties' => array(
+                        'type' => 'string',
+                        'minLength' => 1,
+                        'maxLength' => 2048,
+                        'data' => array(
+                            'shape_name' => 'IdentityProviderName',
+                            'key_pattern' => '/[\\w._/-]+/',
+                        ),
+                    ),
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Thrown for missing or bad input parameter(s).',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Thrown when the requested resource (for example, a dataset or record) does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Thrown when a user is not authorized to access the requested resource.',
+                    'class' => 'NotAuthorizedException',
+                ),
+                array(
+                    'reason' => 'Thrown when a user tries to use a login which is already linked to another account.',
+                    'class' => 'ResourceConflictException',
+                ),
+                array(
+                    'reason' => 'Thrown when a request is throttled.',
+                    'class' => 'TooManyRequestsException',
+                ),
+                array(
+                    'reason' => 'Thrown if the identity pool has no role associated for the given auth type (auth/unauth) or if the AssumeRole fails.',
+                    'class' => 'InvalidIdentityPoolConfigurationException',
+                ),
+                array(
+                    'reason' => 'Thrown when the service encounters an error during processing the request.',
+                    'class' => 'InternalErrorException',
+                ),
+                array(
+                    'reason' => 'An exception thrown when a dependent service such as Facebook or Twitter is not responding',
+                    'class' => 'ExternalServiceException',
+                ),
+            ),
+        ),
         'GetId' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -248,7 +420,6 @@ return array (
                     'default' => 'AWSCognitoIdentityService.GetId',
                 ),
                 'AccountId' => array(
-                    'required' => true,
                     'type' => 'string',
                     'location' => 'json',
                     'minLength' => 1,
@@ -270,7 +441,7 @@ return array (
                         'maxLength' => 2048,
                         'data' => array(
                             'shape_name' => 'IdentityProviderName',
-                            'key_pattern' => '/[\\w._-]+/',
+                            'key_pattern' => '/[\\w._/-]+/',
                         ),
                     ),
                 ),
@@ -304,6 +475,66 @@ return array (
                     'reason' => 'Thrown when the total number of user pools has exceeded a preset limit.',
                     'class' => 'LimitExceededException',
                 ),
+                array(
+                    'reason' => 'An exception thrown when a dependent service such as Facebook or Twitter is not responding',
+                    'class' => 'ExternalServiceException',
+                ),
+            ),
+        ),
+        'GetIdentityPoolRoles' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'GetIdentityPoolRolesResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'AWSCognitoIdentityService.GetIdentityPoolRoles',
+                ),
+                'IdentityPoolId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 50,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Thrown for missing or bad input parameter(s).',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Thrown when the requested resource (for example, a dataset or record) does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Thrown when a user is not authorized to access the requested resource.',
+                    'class' => 'NotAuthorizedException',
+                ),
+                array(
+                    'reason' => 'Thrown when a user tries to use a login which is already linked to another account.',
+                    'class' => 'ResourceConflictException',
+                ),
+                array(
+                    'reason' => 'Thrown when a request is throttled.',
+                    'class' => 'TooManyRequestsException',
+                ),
+                array(
+                    'reason' => 'Thrown when the service encounters an error during processing the request.',
+                    'class' => 'InternalErrorException',
+                ),
             ),
         ),
         'GetOpenIdToken' => array(
@@ -343,7 +574,7 @@ return array (
                         'maxLength' => 2048,
                         'data' => array(
                             'shape_name' => 'IdentityProviderName',
-                            'key_pattern' => '/[\\w._-]+/',
+                            'key_pattern' => '/[\\w._/-]+/',
                         ),
                     ),
                 ),
@@ -373,6 +604,10 @@ return array (
                     'reason' => 'Thrown when the service encounters an error during processing the request.',
                     'class' => 'InternalErrorException',
                 ),
+                array(
+                    'reason' => 'An exception thrown when a dependent service such as Facebook or Twitter is not responding',
+                    'class' => 'ExternalServiceException',
+                ),
             ),
         ),
         'GetOpenIdTokenForDeveloperIdentity' => array(
@@ -419,7 +654,7 @@ return array (
                         'maxLength' => 2048,
                         'data' => array(
                             'shape_name' => 'IdentityProviderName',
-                            'key_pattern' => '/[\\w._-]+/',
+                            'key_pattern' => '/[\\w._/-]+/',
                         ),
                     ),
                 ),
@@ -501,6 +736,11 @@ return array (
                     'location' => 'json',
                     'minLength' => 1,
                 ),
+                'HideDisabled' => array(
+                    'type' => 'boolean',
+                    'format' => 'boolean-string',
+                    'location' => 'json',
+                ),
             ),
             'errorResponses' => array(
                 array(
@@ -615,6 +855,8 @@ return array (
                 'DeveloperUserIdentifier' => array(
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 1024,
                 ),
                 'MaxResults' => array(
                     'type' => 'numeric',
@@ -680,11 +922,15 @@ return array (
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 1024,
                 ),
                 'DestinationUserIdentifier' => array(
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 1024,
                 ),
                 'DeveloperProviderName' => array(
                     'required' => true,
@@ -728,6 +974,80 @@ return array (
                 ),
             ),
         ),
+        'SetIdentityPoolRoles' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'AWSCognitoIdentityService.SetIdentityPoolRoles',
+                ),
+                'IdentityPoolId' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 50,
+                ),
+                'Roles' => array(
+                    'required' => true,
+                    'type' => 'object',
+                    'location' => 'json',
+                    'additionalProperties' => array(
+                        'type' => 'string',
+                        'minLength' => 20,
+                        'maxLength' => 2048,
+                        'data' => array(
+                            'shape_name' => 'RoleType',
+                            'key_pattern' => '/(un)?authenticated/',
+                        ),
+                    ),
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Thrown for missing or bad input parameter(s).',
+                    'class' => 'InvalidParameterException',
+                ),
+                array(
+                    'reason' => 'Thrown when the requested resource (for example, a dataset or record) does not exist.',
+                    'class' => 'ResourceNotFoundException',
+                ),
+                array(
+                    'reason' => 'Thrown when a user is not authorized to access the requested resource.',
+                    'class' => 'NotAuthorizedException',
+                ),
+                array(
+                    'reason' => 'Thrown when a user tries to use a login which is already linked to another account.',
+                    'class' => 'ResourceConflictException',
+                ),
+                array(
+                    'reason' => 'Thrown when a request is throttled.',
+                    'class' => 'TooManyRequestsException',
+                ),
+                array(
+                    'reason' => 'Thrown when the service encounters an error during processing the request.',
+                    'class' => 'InternalErrorException',
+                ),
+                array(
+                    'reason' => 'Thrown if there are parallel requests to modify a resource.',
+                    'class' => 'ConcurrentModificationException',
+                ),
+            ),
+        ),
         'UnlinkDeveloperIdentity' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -774,6 +1094,8 @@ return array (
                     'required' => true,
                     'type' => 'string',
                     'location' => 'json',
+                    'minLength' => 1,
+                    'maxLength' => 1024,
                 ),
             ),
             'errorResponses' => array(
@@ -841,7 +1163,7 @@ return array (
                         'maxLength' => 2048,
                         'data' => array(
                             'shape_name' => 'IdentityProviderName',
-                            'key_pattern' => '/[\\w._-]+/',
+                            'key_pattern' => '/[\\w._/-]+/',
                         ),
                     ),
                 ),
@@ -882,6 +1204,10 @@ return array (
                     'reason' => 'Thrown when the service encounters an error during processing the request.',
                     'class' => 'InternalErrorException',
                 ),
+                array(
+                    'reason' => 'An exception thrown when a dependent service such as Facebook or Twitter is not responding',
+                    'class' => 'ExternalServiceException',
+                ),
             ),
         ),
         'UpdateIdentityPool' => array(
@@ -934,7 +1260,7 @@ return array (
                         'maxLength' => 128,
                         'data' => array(
                             'shape_name' => 'IdentityProviderName',
-                            'key_pattern' => '/[\\w._-]+/',
+                            'key_pattern' => '/[\\w._/-]+/',
                         ),
                     ),
                 ),
@@ -948,7 +1274,7 @@ return array (
                     'type' => 'array',
                     'location' => 'json',
                     'items' => array(
-                        'name' => 'OIDCProviderARN',
+                        'name' => 'ARNString',
                         'type' => 'string',
                         'minLength' => 20,
                         'maxLength' => 2048,
@@ -980,6 +1306,10 @@ return array (
                     'reason' => 'Thrown when the service encounters an error during processing the request.',
                     'class' => 'InternalErrorException',
                 ),
+                array(
+                    'reason' => 'Thrown if there are parallel requests to modify a resource.',
+                    'class' => 'ConcurrentModificationException',
+                ),
             ),
         ),
     ),
@@ -1015,16 +1345,92 @@ return array (
                     'type' => 'array',
                     'location' => 'json',
                     'items' => array(
-                        'name' => 'OIDCProviderARN',
+                        'name' => 'ARNString',
                         'type' => 'string',
                     ),
                 ),
             ),
         ),
+        'DeleteIdentitiesResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'UnprocessedIdentityIds' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'UnprocessedIdentityId',
+                        'type' => 'object',
+                        'properties' => array(
+                            'IdentityId' => array(
+                                'type' => 'string',
+                            ),
+                            'ErrorCode' => array(
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+            ),
+        ),
         'EmptyOutput' => array(
             'type' => 'object',
             'additionalProperties' => true,
         ),
+        'IdentityDescription' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'IdentityId' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'Logins' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'IdentityProviderName',
+                        'type' => 'string',
+                    ),
+                ),
+                'CreationDate' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'LastModifiedDate' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+            ),
+        ),
+        'GetCredentialsForIdentityResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'IdentityId' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'Credentials' => array(
+                    'type' => 'object',
+                    'location' => 'json',
+                    'properties' => array(
+                        'AccessKeyId' => array(
+                            'type' => 'string',
+                        ),
+                        'SecretKey' => array(
+                            'type' => 'string',
+                        ),
+                        'SessionToken' => array(
+                            'type' => 'string',
+                        ),
+                        'Expiration' => array(
+                            'type' => 'string',
+                        ),
+                    ),
+                ),
+            ),
+        ),
         'GetIdResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
@@ -1035,6 +1441,23 @@ return array (
                 ),
             ),
         ),
+        'GetIdentityPoolRolesResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'IdentityPoolId' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
+                'Roles' => array(
+                    'type' => 'object',
+                    'location' => 'json',
+                    'additionalProperties' => array(
+                        'type' => 'string',
+                    ),
+                ),
+            ),
+        ),
         'GetOpenIdTokenResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
@@ -1088,6 +1511,12 @@ return array (
                                     'type' => 'string',
                                 ),
                             ),
+                            'CreationDate' => array(
+                                'type' => 'string',
+                            ),
+                            'LastModifiedDate' => array(
+                                'type' => 'string',
+                            ),
                         ),
                     ),
                 ),
