@@ -75,6 +75,58 @@ return array (
                 ),
             ),
         ),
+        'DeleteTagsForDomain' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Route53Domains_v20140515.DeleteTagsForDomain',
+                ),
+                'DomainName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'maxLength' => 255,
+                ),
+                'TagsToDelete' => array(
+                    'required' => true,
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'TagKey',
+                        'type' => 'string',
+                    ),
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'The requested item is not acceptable. For example, for an OperationId it may refer to the ID of an operation that is already completed. For a domain name, it may not be a valid domain name or belong to the requester account.',
+                    'class' => 'InvalidInputException',
+                ),
+                array(
+                    'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
+                    'class' => 'OperationLimitExceededException',
+                ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
+            ),
+        ),
         'DisableDomainAutoRenew' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -108,6 +160,10 @@ return array (
                     'reason' => 'The requested item is not acceptable. For example, for an OperationId it may refer to the ID of an operation that is already completed. For a domain name, it may not be a valid domain name or belong to the requester account.',
                     'class' => 'InvalidInputException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'DisableDomainTransferLock' => array(
@@ -155,6 +211,10 @@ return array (
                     'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
                     'class' => 'OperationLimitExceededException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'EnableDomainAutoRenew' => array(
@@ -190,6 +250,10 @@ return array (
                     'reason' => 'The requested item is not acceptable. For example, for an OperationId it may refer to the ID of an operation that is already completed. For a domain name, it may not be a valid domain name or belong to the requester account.',
                     'class' => 'InvalidInputException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'EnableDomainTransferLock' => array(
@@ -237,6 +301,10 @@ return array (
                     'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
                     'class' => 'OperationLimitExceededException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'GetDomainDetail' => array(
@@ -272,6 +340,10 @@ return array (
                     'reason' => 'The requested item is not acceptable. For example, for an OperationId it may refer to the ID of an operation that is already completed. For a domain name, it may not be a valid domain name or belong to the requester account.',
                     'class' => 'InvalidInputException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'GetOperationDetail' => array(
@@ -387,6 +459,49 @@ return array (
                 ),
             ),
         ),
+        'ListTagsForDomain' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'ListTagsForDomainResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Route53Domains_v20140515.ListTagsForDomain',
+                ),
+                'DomainName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'maxLength' => 255,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'The requested item is not acceptable. For example, for an OperationId it may refer to the ID of an operation that is already completed. For a domain name, it may not be a valid domain name or belong to the requester account.',
+                    'class' => 'InvalidInputException',
+                ),
+                array(
+                    'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
+                    'class' => 'OperationLimitExceededException',
+                ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
+            ),
+        ),
         'RegisterDomain' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -732,6 +847,10 @@ return array (
                     'reason' => 'The requested item is not acceptable. For example, for an OperationId it may refer to the ID of an operation that is already completed. For a domain name, it may not be a valid domain name or belong to the requester account.',
                     'class' => 'InvalidInputException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'TransferDomain' => array(
@@ -774,7 +893,6 @@ return array (
                     'maximum' => 10,
                 ),
                 'Nameservers' => array(
-                    'required' => true,
                     'type' => 'array',
                     'location' => 'json',
                     'items' => array(
@@ -1342,6 +1460,10 @@ return array (
                     'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
                     'class' => 'OperationLimitExceededException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'UpdateDomainContactPrivacy' => array(
@@ -1404,6 +1526,10 @@ return array (
                     'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
                     'class' => 'OperationLimitExceededException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
         'UpdateDomainNameservers' => array(
@@ -1433,6 +1559,10 @@ return array (
                     'location' => 'json',
                     'maxLength' => 255,
                 ),
+                'FIAuthKey' => array(
+                    'type' => 'string',
+                    'location' => 'json',
+                ),
                 'Nameservers' => array(
                     'required' => true,
                     'type' => 'array',
@@ -1475,6 +1605,69 @@ return array (
                     'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
                     'class' => 'OperationLimitExceededException',
                 ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
+            ),
+        ),
+        'UpdateTagsForDomain' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\JsonCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Content-Type' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'application/x-amz-json-1.1',
+                ),
+                'command.expects' => array(
+                    'static' => true,
+                    'default' => 'application/json',
+                ),
+                'X-Amz-Target' => array(
+                    'static' => true,
+                    'location' => 'header',
+                    'default' => 'Route53Domains_v20140515.UpdateTagsForDomain',
+                ),
+                'DomainName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'json',
+                    'maxLength' => 255,
+                ),
+                'TagsToUpdate' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'Tag',
+                        'type' => 'object',
+                        'properties' => array(
+                            'Key' => array(
+                                'type' => 'string',
+                            ),
+                            'Value' => array(
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'The requested item is not acceptable. For example, for an OperationId it may refer to the ID of an operation that is already completed. For a domain name, it may not be a valid domain name or belong to the requester account.',
+                    'class' => 'InvalidInputException',
+                ),
+                array(
+                    'reason' => 'The number of operations or jobs running exceeded the allowed threshold for the account.',
+                    'class' => 'OperationLimitExceededException',
+                ),
+                array(
+                    'reason' => 'Amazon Route 53 does not support this top-level domain.',
+                    'class' => 'UnsupportedTLDException',
+                ),
             ),
         ),
     ),
@@ -1885,6 +2078,28 @@ return array (
                 ),
             ),
         ),
+        'ListTagsForDomainResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'TagList' => array(
+                    'type' => 'array',
+                    'location' => 'json',
+                    'items' => array(
+                        'name' => 'Tag',
+                        'type' => 'object',
+                        'properties' => array(
+                            'Key' => array(
+                                'type' => 'string',
+                            ),
+                            'Value' => array(
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                ),
+            ),
+        ),
         'RegisterDomainResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
@@ -1946,4 +2161,18 @@ return array (
             ),
         ),
     ),
+    'iterators' => array(
+        'ListDomains' => array(
+            'limit_key' => 'MaxItems',
+            'input_token' => 'Marker',
+            'output_token' => 'NextPageMarker',
+            'result_key' => 'Domains',
+        ),
+        'ListOperations' => array(
+            'limit_key' => 'MaxItems',
+            'input_token' => 'Marker',
+            'output_token' => 'NextPageMarker',
+            'result_key' => 'Operations',
+        ),
+    ),
 );
