@@ -65,6 +65,37 @@ return array (
                 ),
             ),
         ),
+        'DeleteIdentityPolicy' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\QueryCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Action' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => 'DeleteIdentityPolicy',
+                ),
+                'Version' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => '2010-12-01',
+                ),
+                'Identity' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+                'PolicyName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                    'maxLength' => 64,
+                ),
+            ),
+        ),
         'DeleteVerifiedEmailAddress' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -148,6 +179,42 @@ return array (
                 ),
             ),
         ),
+        'GetIdentityPolicies' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\QueryCommand',
+            'responseClass' => 'GetIdentityPoliciesResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Action' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => 'GetIdentityPolicies',
+                ),
+                'Version' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => '2010-12-01',
+                ),
+                'Identity' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+                'PolicyNames' => array(
+                    'required' => true,
+                    'type' => 'array',
+                    'location' => 'aws.query',
+                    'sentAs' => 'PolicyNames.member',
+                    'items' => array(
+                        'name' => 'PolicyName',
+                        'type' => 'string',
+                        'minLength' => 1,
+                        'maxLength' => 64,
+                    ),
+                ),
+            ),
+        ),
         'GetIdentityVerificationAttributes' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -246,6 +313,30 @@ return array (
                 ),
             ),
         ),
+        'ListIdentityPolicies' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\QueryCommand',
+            'responseClass' => 'ListIdentityPoliciesResponse',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Action' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => 'ListIdentityPolicies',
+                ),
+                'Version' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => '2010-12-01',
+                ),
+                'Identity' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+            ),
+        ),
         'ListVerifiedEmailAddresses' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -266,6 +357,49 @@ return array (
                 ),
             ),
         ),
+        'PutIdentityPolicy' => array(
+            'httpMethod' => 'POST',
+            'uri' => '/',
+            'class' => 'Aws\\Common\\Command\\QueryCommand',
+            'responseClass' => 'EmptyOutput',
+            'responseType' => 'model',
+            'parameters' => array(
+                'Action' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => 'PutIdentityPolicy',
+                ),
+                'Version' => array(
+                    'static' => true,
+                    'location' => 'aws.query',
+                    'default' => '2010-12-01',
+                ),
+                'Identity' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+                'PolicyName' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                    'maxLength' => 64,
+                ),
+                'Policy' => array(
+                    'required' => true,
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                    'minLength' => 1,
+                ),
+            ),
+            'errorResponses' => array(
+                array(
+                    'reason' => 'Indicates that the provided policy is invalid. Check the error stack for more information about what caused the error.',
+                    'class' => 'InvalidPolicyException',
+                ),
+            ),
+        ),
         'SendEmail' => array(
             'httpMethod' => 'POST',
             'uri' => '/',
@@ -382,6 +516,14 @@ return array (
                     'type' => 'string',
                     'location' => 'aws.query',
                 ),
+                'SourceArn' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+                'ReturnPathArn' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
             ),
             'errorResponses' => array(
                 array(
@@ -431,6 +573,18 @@ return array (
                         ),
                     ),
                 ),
+                'FromArn' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+                'SourceArn' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
+                'ReturnPathArn' => array(
+                    'type' => 'string',
+                    'location' => 'aws.query',
+                ),
             ),
             'errorResponses' => array(
                 array(
@@ -737,6 +891,42 @@ return array (
                 ),
             ),
         ),
+        'GetIdentityPoliciesResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'Policies' => array(
+                    'type' => 'array',
+                    'location' => 'xml',
+                    'filters' => array(
+                        array(
+                            'method' => 'Aws\\Common\\Command\\XmlResponseLocationVisitor::xmlMap',
+                            'args' => array(
+                                '@value',
+                                'entry',
+                                'key',
+                                'value',
+                            ),
+                        ),
+                    ),
+                    'items' => array(
+                        'name' => 'entry',
+                        'type' => 'object',
+                        'sentAs' => 'entry',
+                        'additionalProperties' => true,
+                        'properties' => array(
+                            'key' => array(
+                                'type' => 'string',
+                            ),
+                            'value' => array(
+                                'type' => 'string',
+                            ),
+                        ),
+                    ),
+                    'additionalProperties' => false,
+                ),
+            ),
+        ),
         'GetIdentityVerificationAttributesResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
@@ -850,6 +1040,21 @@ return array (
                 ),
             ),
         ),
+        'ListIdentityPoliciesResponse' => array(
+            'type' => 'object',
+            'additionalProperties' => true,
+            'properties' => array(
+                'PolicyNames' => array(
+                    'type' => 'array',
+                    'location' => 'xml',
+                    'items' => array(
+                        'name' => 'PolicyName',
+                        'type' => 'string',
+                        'sentAs' => 'member',
+                    ),
+                ),
+            ),
+        ),
         'ListVerifiedEmailAddressesResponse' => array(
             'type' => 'object',
             'additionalProperties' => true,
